@@ -191,6 +191,7 @@ impl HolochainP2pCellT for PassThroughNetwork {
     async fn publish(
         &self,
         _request_validation_receipt: bool,
+        _countersigning_session: bool,
         _dht_hash: holo_hash::AnyDhtHash,
         _ops: Vec<(holo_hash::DhtOpHash, holochain_types::dht_op::DhtOp)>,
         _timeout_ms: Option<u64>,
@@ -205,6 +206,18 @@ impl HolochainP2pCellT for PassThroughNetwork {
     ) -> actor::HolochainP2pResult<()> {
         todo!()
     }
+
+    async fn countersigning_authority_response(
+        &self,
+        _agents: Vec<AgentPubKey>,
+        _response: Vec<holochain_zome_types::SignedHeader>,
+    ) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
+
+    async fn new_integrated_data(&self) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
 }
 
 pub fn fill_db(env: &EnvWrite, op: DhtOpHashed) {
@@ -343,6 +356,7 @@ impl HolochainP2pCellT for MockNetwork {
     async fn publish(
         &self,
         _request_validation_receipt: bool,
+        _countersigning_session: bool,
         _dht_hash: holo_hash::AnyDhtHash,
         _ops: Vec<(holo_hash::DhtOpHash, holochain_types::dht_op::DhtOp)>,
         _timeout_ms: Option<u64>,
@@ -357,6 +371,18 @@ impl HolochainP2pCellT for MockNetwork {
     ) -> actor::HolochainP2pResult<()> {
         todo!()
     }
+
+    async fn countersigning_authority_response(
+        &self,
+        _agents: Vec<AgentPubKey>,
+        _response: Vec<holochain_zome_types::SignedHeader>,
+    ) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
+
+    async fn new_integrated_data(&self) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
 }
 
 pub fn wire_to_shh<T: TryInto<SignedHeader> + Clone>(op: &T) -> SignedHeaderHashed {
